@@ -1,24 +1,27 @@
 use std::{collections::HashSet, path::Path, str::FromStr};
 
-use serde::Deserialize;
+use anyhow::Context;
+use serde::{Deserialize, Deserializer};
+use tracing::warn;
+use yazi_fs::File;
 
-use super::{Fetcher, Preloader, Previewer};
-use crate::{plugin::MAX_PREWORKERS, Preset};
+use super::{Fetcher, Preloader, Previewer, Spotter};
+use crate::{Preset, plugin::MAX_PREWORKERS};
 
-#[derive(Deserialize)]
 pub struct Plugin {
 	pub fetchers:   Vec<Fetcher>,
+	pub spotters:   Vec<Spotter>,
 	pub preloaders: Vec<Preloader>,
 	pub previewers: Vec<Previewer>,
 }
 
 impl Plugin {
-	pub fn fetchers<'a>(
-		&'a self,
+	pub fn fetchers<'a, 'b: 'a>(
+		&'b self,
 		path: &'a Path,
 		mime: &'a str,
-		factor: impl Fn(&str) -> bool + Copy,
-	) -> impl Iterator<Item = &'a Fetcher> {
+		factor: impl Fn(&str) -> bool + Copy + 'a,
+	) -> impl Iterator<Item = &'b Fetcher> + 'a {
 		let mut seen = HashSet::new();
 		self.fetchers.iter().filter(move |&f| {
 			if seen.contains(&f.id) || !f.matches(path, mime, factor) {
@@ -29,16 +32,41 @@ impl Plugin {
 		})
 	}
 
+	pub fn mime_fetchers(&self, files: Vec<File>) -> impl Iterator<Item = (&Fetcher, Vec<File>)> {
+		let mut tasks: [Vec<_>; MAX_PREWORKERS as usize] = Default::default();
+		for f in files {
+			let factors = |s: &str| match s {
+				"dummy" => f.cha.is_dummy(),
+				_ => false,
+			};
+
+			let found = self.fetchers.iter().find(|&g| g.id == "mime" && g.matches(&f.url, "", factors));
+			if let Some(g) = found {
+				tasks[g.idx as usize].push(f);
+			} else {
+				warn!("No mime fetcher for {f:?}");
+			}
+		}
+
+		tasks.into_iter().enumerate().filter_map(|(i, tasks)| {
+			if tasks.is_empty() { None } else { Some((&self.fetchers[i], tasks)) }
+		})
+	}
+
 	#[inline]
 	pub fn fetchers_mask(&self) -> u32 {
 		self.fetchers.iter().fold(0, |n, f| if f.mime.is_some() { n } else { n | 1 << f.idx as u32 })
 	}
 
-	pub fn preloaders<'a>(
-		&'a self,
+	pub fn spotter(&self, path: &Path, mime: &str) -> Option<&Spotter> {
+		self.spotters.iter().find(|&p| p.matches(path, mime))
+	}
+
+	pub fn preloaders<'a, 'b: 'a>(
+		&'b self,
 		path: &'a Path,
 		mime: &'a str,
-	) -> impl Iterator<Item = &'a Preloader> {
+	) -> impl Iterator<Item = &'b Preloader> + 'a {
 		let mut next = true;
 		self.preloaders.iter().filter(move |&p| {
 			if !next || !p.matches(path, mime) {
@@ -55,9 +83,18 @@ impl Plugin {
 }
 
 impl FromStr for Plugin {
-	type Err = toml::de::Error;
+	type Err = anyhow::Error;
 
 	fn from_str(s: &str) -> Result<Self, Self::Err> {
+		toml::from_str(s).context("Failed to parse the [plugin] section in your yazi.toml")
+	}
+}
+
+impl<'de> Deserialize<'de> for Plugin {
+	fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+	where
+		D: Deserializer<'de>,
+	{
 		#[derive(Deserialize)]
 		struct Outer {
 			plugin: Shadow,
@@ -71,6 +108,12 @@ impl FromStr for Plugin {
 			#[serde(default)]
 			append_fetchers:  Vec<Fetcher>,
 
+			spotters:         Vec<Spotter>,
+			#[serde(default)]
+			prepend_spotters: Vec<Spotter>,
+			#[serde(default)]
+			append_spotters:  Vec<Spotter>,
+
 			preloaders:         Vec<Preloader>,
 			#[serde(default)]
 			prepend_preloaders: Vec<Preloader>,
@@ -84,7 +127,13 @@ impl FromStr for Plugin {
 			append_previewers:  Vec<Previewer>,
 		}
 
-		let mut shadow = toml::from_str::<Outer>(s)?.plugin;
+		let mut shadow = Outer::deserialize(deserializer)?.plugin;
+		if shadow.append_spotters.iter().any(|r| r.any_file()) {
+			shadow.spotters.retain(|r| !r.any_file());
+		}
+		if shadow.append_spotters.iter().any(|r| r.any_dir()) {
+			shadow.spotters.retain(|r| !r.any_dir());
+		}
 		if shadow.append_previewers.iter().any(|r| r.any_file()) {
 			shadow.previewers.retain(|r| !r.any_file());
 		}
@@ -93,11 +142,13 @@ impl FromStr for Plugin {
 		}
 
 		shadow.fetchers =
-			Preset::mix(shadow.fetchers, shadow.prepend_fetchers, shadow.append_fetchers).collect();
+			Preset::mix(shadow.prepend_fetchers, shadow.fetchers, shadow.append_fetchers).collect();
+		shadow.spotters =
+			Preset::mix(shadow.prepend_spotters, shadow.spotters, shadow.append_spotters).collect();
 		shadow.preloaders =
-			Preset::mix(shadow.preloaders, shadow.prepend_preloaders, shadow.append_preloaders).collect();
+			Preset::mix(shadow.prepend_preloaders, shadow.preloaders, shadow.append_preloaders).collect();
 		shadow.previewers =
-			Preset::mix(shadow.previewers, shadow.prepend_previewers, shadow.append_previewers).collect();
+			Preset::mix(shadow.prepend_previewers, shadow.previewers, shadow.append_previewers).collect();
 
 		if shadow.fetchers.len() + shadow.preloaders.len() > MAX_PREWORKERS as usize {
 			panic!("Fetchers and preloaders exceed the limit of {MAX_PREWORKERS}");
@@ -112,6 +163,7 @@ impl FromStr for Plugin {
 
 		Ok(Self {
 			fetchers:   shadow.fetchers,
+			spotters:   shadow.spotters,
 			preloaders: shadow.preloaders,
 			previewers: shadow.previewers,
 		})
