@@ -1,5 +1,6 @@
 use std::str::FromStr;
 
+use anyhow::Context;
 use serde::Deserialize;
 
 use super::{Offset, Origin};
@@ -14,7 +15,7 @@ pub struct Input {
 	pub cd_offset: Offset,
 
 	// create
-	pub create_title:  String,
+	pub create_title:  InputCreateTitle,
 	pub create_origin: Origin,
 	pub create_offset: Offset,
 
@@ -49,7 +50,7 @@ impl Input {
 }
 
 impl FromStr for Input {
-	type Err = toml::de::Error;
+	type Err = anyhow::Error;
 
 	fn from_str(s: &str) -> Result<Self, Self::Err> {
 		#[derive(Deserialize)]
@@ -57,6 +58,26 @@ impl FromStr for Input {
 			input: Input,
 		}
 
-		Ok(toml::from_str::<Outer>(s)?.input)
+		let outer = toml::from_str::<Outer>(s)
+			.context("Failed to parse the [input] section in your yazi.toml")?;
+
+		Ok(outer.input)
+	}
+}
+
+// TODO: Remove in v0.3.6
+#[derive(Deserialize)]
+#[serde(untagged)]
+pub enum InputCreateTitle {
+	One(String),
+	Two([String; 2]),
+}
+
+impl InputCreateTitle {
+	pub fn as_array(&self) -> [&str; 2] {
+		match self {
+			Self::One(s) => [s, "Create (dir):"],
+			Self::Two(a) => [&a[0], &a[1]],
+		}
 	}
 }
