@@ -2,7 +2,8 @@ use std::collections::HashMap;
 
 use anyhow::Result;
 use serde::{Deserialize, Deserializer};
-use yazi_shared::{fs::File, theme::{Color, Icon, Style}, Condition};
+use yazi_fs::File;
+use yazi_shared::{Condition, theme::{Color, Icon, Style}};
 
 use crate::{Pattern, Preset};
 
@@ -48,7 +49,7 @@ impl Icons {
 
 	#[inline]
 	fn match_by_name(&self, file: &File) -> Option<&Icon> {
-		let name = file.name()?.to_str()?;
+		let name = file.name().to_str()?;
 		if file.is_dir() {
 			self.dirs.get(name).or_else(|| self.dirs.get(&name.to_ascii_lowercase()))
 		} else {
@@ -56,9 +57,15 @@ impl Icons {
 				.files
 				.get(name)
 				.or_else(|| self.files.get(&name.to_ascii_lowercase()))
-				.or_else(|| self.exts.get(file.url.extension()?.to_str()?))
+				.or_else(|| self.match_by_ext(file))
 		}
 	}
+
+	#[inline]
+	fn match_by_ext(&self, file: &File) -> Option<&Icon> {
+		let ext = file.url.extension()?.to_str()?;
+		self.exts.get(ext).or_else(|| self.exts.get(&ext.to_ascii_lowercase()))
+	}
 }
 
 impl<'de> Deserialize<'de> for Icons {
@@ -100,42 +107,32 @@ impl<'de> Deserialize<'de> for Icons {
 		}
 		#[derive(Deserialize)]
 		pub struct ShadowPat {
-			name:     Pattern,
-			text:     String,
-			fg_dark:  Option<Color>,
-			#[allow(dead_code)]
-			fg_light: Option<Color>,
+			name: Pattern,
+			text: String,
+			fg:   Option<Color>,
 		}
 		#[derive(Deserialize)]
 		pub struct ShadowStr {
-			name:     String,
-			text:     String,
-			fg_dark:  Option<Color>,
-			#[allow(dead_code)]
-			fg_light: Option<Color>,
+			name: String,
+			text: String,
+			fg:   Option<Color>,
 		}
 		#[derive(Deserialize)]
 		pub struct ShadowCond {
 			#[serde(rename = "if")]
-			if_:      Condition,
-			text:     String,
-			fg_dark:  Option<Color>,
-			#[allow(dead_code)]
-			fg_light: Option<Color>,
+			if_:  Condition,
+			text: String,
+			fg:   Option<Color>,
 		}
 
 		let shadow = Shadow::deserialize(deserializer)?;
 
-		let globs = Preset::mix(shadow.globs, shadow.prepend_globs, shadow.append_globs)
-			.map(|v| {
-				(v.name, Icon { text: v.text, style: Style { fg: v.fg_dark, ..Default::default() } })
-			})
+		let globs = Preset::mix(shadow.prepend_globs, shadow.globs, shadow.append_globs)
+			.map(|v| (v.name, Icon { text: v.text, style: Style { fg: v.fg, ..Default::default() } }))
 			.collect();
 
-		let conds = Preset::mix(shadow.conds, shadow.prepend_conds, shadow.append_conds)
-			.map(|v| {
-				(v.if_, Icon { text: v.text, style: Style { fg: v.fg_dark, ..Default::default() } })
-			})
+		let conds = Preset::mix(shadow.prepend_conds, shadow.conds, shadow.append_conds)
+			.map(|v| (v.if_, Icon { text: v.text, style: Style { fg: v.fg, ..Default::default() } }))
 			.collect();
 
 		fn as_map(it: impl Iterator<Item = ShadowStr>) -> HashMap<String, Icon> {
@@ -143,7 +140,7 @@ impl<'de> Deserialize<'de> for Icons {
 			for v in it {
 				map
 					.entry(v.name)
-					.or_insert(Icon { text: v.text, style: Style { fg: v.fg_dark, ..Default::default() } });
+					.or_insert(Icon { text: v.text, style: Style { fg: v.fg, ..Default::default() } });
 			}
 			map.shrink_to_fit();
 			map
@@ -151,9 +148,9 @@ impl<'de> Deserialize<'de> for Icons {
 
 		Ok(Self {
 			globs,
-			dirs: as_map(Preset::mix(shadow.dirs, shadow.prepend_dirs, shadow.append_dirs)),
-			files: as_map(Preset::mix(shadow.files, shadow.prepend_files, shadow.append_files)),
-			exts: as_map(Preset::mix(shadow.exts, shadow.prepend_exts, shadow.append_exts)),
+			dirs: as_map(Preset::mix(shadow.prepend_dirs, shadow.dirs, shadow.append_dirs)),
+			files: as_map(Preset::mix(shadow.prepend_files, shadow.files, shadow.append_files)),
+			exts: as_map(Preset::mix(shadow.prepend_exts, shadow.exts, shadow.append_exts)),
 			conds,
 		})
 	}
