@@ -1,8 +1,9 @@
 use std::{path::PathBuf, str::FromStr};
 
+use anyhow::Context;
 use serde::{Deserialize, Serialize};
 use validator::Validate;
-use yazi_shared::{fs::expand_path, theme::Style, Xdg};
+use yazi_shared::theme::Style;
 
 use super::{Filetype, Flavor, Icons};
 
@@ -10,9 +11,11 @@ use super::{Filetype, Flavor, Icons};
 pub struct Theme {
 	pub flavor:     Flavor,
 	pub manager:    Manager,
+	mode:           Mode,
 	status:         Status,
 	pub input:      Input,
-	pub select:     Select,
+	pub confirm:    Confirm,
+	pub pick:       Pick,
 	pub completion: Completion,
 	pub tasks:      Tasks,
 	pub which:      Which,
@@ -30,17 +33,10 @@ impl FromStr for Theme {
 	type Err = anyhow::Error;
 
 	fn from_str(s: &str) -> Result<Self, Self::Err> {
-		let mut theme: Self = toml::from_str(s)?;
+		let theme: Self = toml::from_str(s).context("Failed to parse your theme.toml")?;
 		theme.manager.validate()?;
 		theme.which.validate()?;
 
-		if theme.flavor.use_.is_empty() {
-			theme.manager.syntect_theme = expand_path(&theme.manager.syntect_theme);
-		} else {
-			theme.manager.syntect_theme =
-				Xdg::config_dir().join(format!("flavors/{}.yazi/tmtheme.xml", theme.flavor.use_));
-		}
-
 		Ok(theme)
 	}
 }
@@ -82,16 +78,22 @@ pub struct Manager {
 	pub syntect_theme: PathBuf,
 }
 
+#[derive(Deserialize, Serialize)]
+struct Mode {
+	pub normal_main: Style,
+	pub normal_alt:  Style,
+
+	pub select_main: Style,
+	pub select_alt:  Style,
+
+	pub unset_main: Style,
+	pub unset_alt:  Style,
+}
+
 #[derive(Deserialize, Serialize)]
 struct Status {
 	pub separator_open:  String,
 	pub separator_close: String,
-	pub separator_style: Style,
-
-	// Mode
-	pub mode_normal: Style,
-	pub mode_select: Style,
-	pub mode_unset:  Style,
 
 	// Progress
 	pub progress_label:  Style,
@@ -99,11 +101,11 @@ struct Status {
 	pub progress_error:  Style,
 
 	// Permissions
-	pub permissions_t: Style,
-	pub permissions_r: Style,
-	pub permissions_w: Style,
-	pub permissions_x: Style,
-	pub permissions_s: Style,
+	pub perm_sep:   Style,
+	pub perm_type:  Style,
+	pub perm_read:  Style,
+	pub perm_write: Style,
+	pub perm_exec:  Style,
 }
 
 #[derive(Deserialize, Serialize)]
@@ -115,7 +117,18 @@ pub struct Input {
 }
 
 #[derive(Deserialize, Serialize)]
-pub struct Select {
+pub struct Confirm {
+	pub border:     Style,
+	pub title:      Style,
+	pub content:    Style,
+	pub list:       Style,
+	pub btn_yes:    Style,
+	pub btn_no:     Style,
+	pub btn_labels: [String; 2],
+}
+
+#[derive(Deserialize, Serialize)]
+pub struct Pick {
 	pub border:   Style,
 	pub active:   Style,
 	pub inactive: Style,
