@@ -1,7 +1,8 @@
 use std::{borrow::Cow, mem, path::{MAIN_SEPARATOR, MAIN_SEPARATOR_STR}};
 
 use tokio::fs;
-use yazi_shared::{emit, event::{Cmd, Data}, render, Layer};
+use yazi_macro::{emit, render};
+use yazi_shared::{Layer, event::{Cmd, CmdCow, Data}};
 
 use crate::completion::Completion;
 
@@ -11,13 +12,13 @@ const SEPARATOR: [char; 2] = ['/', '\\'];
 #[cfg(not(windows))]
 const SEPARATOR: char = std::path::MAIN_SEPARATOR;
 
-pub struct Opt {
-	word:   String,
+struct Opt {
+	word:   Cow<'static, str>,
 	ticket: usize,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
 		Self {
 			word:   c.take_first_str().unwrap_or_default(),
 			ticket: c.get("ticket").and_then(Data::as_usize).unwrap_or(0),
@@ -26,8 +27,8 @@ impl From<Cmd> for Opt {
 }
 
 impl Completion {
-	pub fn trigger(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn trigger(&mut self, opt: Opt) {
 		if opt.ticket < self.ticket {
 			return;
 		}
@@ -39,7 +40,7 @@ impl Completion {
 
 		if self.caches.contains_key(&parent) {
 			return self.show(
-				Cmd::new("show").with("cache-name", parent).with("word", child).with("ticket", opt.ticket),
+				Cmd::default().with("cache-name", parent).with("word", child).with("ticket", opt.ticket),
 			);
 		}
 
