@@ -1,26 +1,26 @@
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::help::Help;
 
-pub struct Opt {
+struct Opt {
 	step: isize,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
 }
 impl From<isize> for Opt {
 	fn from(step: isize) -> Self { Self { step } }
 }
 
 impl Help {
-	#[inline]
-	pub fn arrow(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn arrow(&mut self, opt: Opt) {
 		let max = self.bindings.len().saturating_sub(1);
 		self.offset = self.offset.min(max);
 		self.cursor = self.cursor.min(max);
 
-		let opt = opt.into() as Opt;
 		if opt.step > 0 {
 			self.next(opt.step as usize);
 		} else {
