@@ -1,6 +1,7 @@
-use std::path::MAIN_SEPARATOR_STR;
+use std::{borrow::Cow, path::MAIN_SEPARATOR_STR};
 
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::input::Input;
 
@@ -10,13 +11,13 @@ const SEPARATOR: [char; 2] = ['/', '\\'];
 #[cfg(not(windows))]
 const SEPARATOR: char = std::path::MAIN_SEPARATOR;
 
-pub struct Opt {
-	word:   String,
+struct Opt {
+	word:   Cow<'static, str>,
 	ticket: usize,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
 		Self {
 			word:   c.take_first_str().unwrap_or_default(),
 			ticket: c.get("ticket").and_then(Data::as_usize).unwrap_or(0),
@@ -25,8 +26,8 @@ impl From<Cmd> for Opt {
 }
 
 impl Input {
-	pub fn complete(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn complete(&mut self, opt: Opt) {
 		if self.ticket != opt.ticket {
 			return;
 		}
@@ -43,7 +44,7 @@ impl Input {
 			return;
 		}
 
-		let delta = new.chars().count() as isize - snap.value.chars().count() as isize;
+		let delta = new.chars().count() as isize - snap.count() as isize;
 		snap.value = new;
 
 		self.move_(delta);
