@@ -1,18 +1,18 @@
-use yazi_shared::{event::Cmd, CharKind};
+use yazi_shared::{CharKind, event::CmdCow};
 
-use crate::input::{op::InputOp, Input};
+use crate::input::{Input, op::InputOp};
 
-pub struct Opt {
+struct Opt {
 	end_of_word: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { end_of_word: c.bool("end-of-word") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { end_of_word: c.bool("end-of-word") } }
 }
 
 impl Input {
-	pub fn forward(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn forward(&mut self, opt: Opt) {
 		let snap = self.snap();
 
 		let mut it = snap.value.chars().skip(snap.cursor).enumerate();
