@@ -1,15 +1,16 @@
 use unicode_width::UnicodeWidthStr;
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
-use crate::input::{op::InputOp, snap::InputSnap, Input};
+use crate::input::{Input, op::InputOp, snap::InputSnap};
 
-pub struct Opt {
+struct Opt {
 	step:         isize,
 	in_operating: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self {
 		Self {
 			step:         c.first().and_then(Data::as_isize).unwrap_or(0),
 			in_operating: c.bool("in-operating"),
@@ -21,9 +22,8 @@ impl From<isize> for Opt {
 }
 
 impl Input {
-	pub fn move_(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
-
+	#[yazi_codegen::command]
+	pub fn move_(&mut self, opt: Opt) {
 		let snap = self.snap();
 		if opt.in_operating && snap.op == InputOp::None {
 			return;
