@@ -2,11 +2,12 @@ use std::ops::Range;
 
 use tokio::sync::mpsc::UnboundedSender;
 use unicode_width::UnicodeWidthStr;
-use yazi_config::{popup::Position, INPUT};
+use yazi_config::{INPUT, popup::Position};
+use yazi_macro::render;
 use yazi_plugin::CLIPBOARD;
-use yazi_shared::{render, InputError};
+use yazi_shared::errors::InputError;
 
-use super::{mode::InputMode, op::InputOp, InputSnap, InputSnaps};
+use super::{InputSnap, InputSnaps, mode::InputMode, op::InputOp};
 
 #[derive(Default)]
 pub struct Input {
