@@ -6,16 +6,7 @@
 	clippy::unit_arg
 )]
 
-pub mod completion;
-pub mod confirm;
-pub mod help;
-pub mod input;
-pub mod manager;
-pub mod notify;
-pub mod select;
-pub mod tab;
-pub mod tasks;
-pub mod which;
+yazi_macro::mod_pub!(completion confirm help input manager notify pick spot tab tasks which);
 
 pub fn init() {
 	manager::WATCHED.with(<_>::default);
