@@ -1,28 +1,29 @@
-use std::collections::HashMap;
+use std::collections::{HashMap, HashSet};
 
 use anyhow::Result;
 use tokio::fs;
 use yazi_config::popup::{ConfirmCfg, InputCfg};
+use yazi_fs::{File, FilesOp, maybe_exists, ok_or_not_found, realname};
 use yazi_proxy::{ConfirmProxy, InputProxy, TabProxy, WATCHER};
-use yazi_shared::{event::Cmd, fs::{maybe_exists, ok_or_not_found, symlink_realpath, File, FilesOp, Url}};
+use yazi_shared::{event::CmdCow, url::{Url, UrnBuf}};
 
 use crate::manager::Manager;
 
-pub struct Opt {
+struct Opt {
 	dir:   bool,
 	force: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { dir: c.bool("dir"), force: c.bool("force") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { dir: c.bool("dir"), force: c.bool("force") } }
 }
 
 impl Manager {
-	pub fn create(&self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn create(&self, opt: Opt) {
 		let cwd = self.cwd().to_owned();
 		tokio::spawn(async move {
-			let mut result = InputProxy::show(InputCfg::create());
+			let mut result = InputProxy::show(InputCfg::create(opt.dir));
 			let Some(Ok(name)) = result.recv().await else {
 				return Ok(());
 			};
@@ -48,9 +49,9 @@ impl Manager {
 
 		if dir {
 			fs::create_dir_all(&new).await?;
-		} else if let Ok(real) = symlink_realpath(&new).await {
+		} else if let Some(real) = realname(&new).await {
 			ok_or_not_found(fs::remove_file(&new).await)?;
-			FilesOp::Deleting(parent.clone(), vec![Url::from(real)]).emit();
+			FilesOp::Deleting(parent.clone(), HashSet::from_iter([UrnBuf::from(real)])).emit();
 			fs::File::create(&new).await?;
 		} else {
 			fs::create_dir_all(&parent).await.ok();
@@ -59,7 +60,7 @@ impl Manager {
 		}
 
 		if let Ok(f) = File::from(new.clone()).await {
-			FilesOp::Upserting(parent, HashMap::from_iter([(f.url(), f)])).emit();
+			FilesOp::Upserting(parent, HashMap::from_iter([(f.urn_owned(), f)])).emit();
 			TabProxy::reveal(&new)
 		}
 		Ok(())
