@@ -2,25 +2,27 @@ use std::time::Duration;
 
 use tokio::{select, time};
 use yazi_config::popup::ConfirmCfg;
+use yazi_macro::emit;
 use yazi_proxy::ConfirmProxy;
-use yazi_shared::{emit, event::{Cmd, EventQuit}};
+use yazi_shared::event::{CmdCow, EventQuit};
 
 use crate::{manager::Manager, tasks::Tasks};
 
 #[derive(Default)]
-pub struct Opt {
+struct Opt {
 	no_cwd_file: bool,
 }
 impl From<()> for Opt {
 	fn from(_: ()) -> Self { Self::default() }
 }
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { no_cwd_file: c.bool("no-cwd-file") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { no_cwd_file: c.bool("no-cwd-file") } }
 }
 
 impl Manager {
-	pub fn quit(&self, opt: impl Into<Opt>, tasks: &Tasks) {
-		let opt = EventQuit { no_cwd_file: opt.into().no_cwd_file, ..Default::default() };
+	#[yazi_codegen::command]
+	pub fn quit(&self, opt: Opt, tasks: &Tasks) {
+		let opt = EventQuit { no_cwd_file: opt.no_cwd_file, ..Default::default() };
 
 		let ongoing = tasks.ongoing().clone();
 		let (left, left_names) = {
