@@ -1,11 +1,12 @@
 use bitflags::bitflags;
+use yazi_macro::{render, render_and};
 use yazi_proxy::{AppProxy, ManagerProxy};
-use yazi_shared::{event::Cmd, render, render_and};
+use yazi_shared::event::CmdCow;
 
 use crate::tab::Tab;
 
 bitflags! {
-	pub struct Opt: u8 {
+	struct Opt: u8 {
 		const FIND   = 0b00001;
 		const VISUAL = 0b00010;
 		const FILTER = 0b00100;
@@ -14,10 +15,10 @@ bitflags! {
 	}
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self {
 		c.args.iter().fold(Opt::empty(), |acc, (k, v)| {
-			match (k.as_str(), v.as_bool().unwrap_or(false)) {
+			match (k.as_str().unwrap_or(""), v.as_bool().unwrap_or(false)) {
 				("all", true) => Self::all(),
 				("find", true) => acc | Self::FIND,
 				("visual", true) => acc | Self::VISUAL,
@@ -31,8 +32,8 @@ impl From<Cmd> for Opt {
 }
 
 impl Tab {
-	pub fn escape(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn escape(&mut self, opt: Opt) {
 		if opt.is_empty() {
 			_ = self.escape_find()
 				|| self.escape_visual()
@@ -85,14 +86,14 @@ impl Tab {
 		}
 
 		self.selected.clear();
-		if self.current.hovered().is_some_and(|h| h.is_dir()) {
+		if self.hovered().is_some_and(|h| h.is_dir()) {
 			ManagerProxy::peek(true);
 		}
 		render_and!(true)
 	}
 
 	pub fn escape_search(&mut self) -> bool {
-		let b = self.current.cwd.is_search();
+		let b = self.cwd().is_search();
 		self.search_stop();
 
 		render_and!(b)
@@ -108,7 +109,7 @@ impl Tab {
 		let urls: Vec<_> =
 			indices.into_iter().filter_map(|i| self.current.files.get(i)).map(|f| &f.url).collect();
 
-		let same = !self.current.cwd.is_search();
+		let same = !self.cwd().is_search();
 		if !select {
 			self.selected.remove_many(&urls, same);
 		} else if self.selected.add_many(&urls, same) != urls.len() {
