@@ -1,12 +1,12 @@
 use std::{borrow::Cow, collections::HashMap, ffi::OsString, mem};
 
-use yazi_config::{open::Opener, OPEN};
-use yazi_shared::fs::Url;
+use yazi_config::{OPEN, open::Opener};
+use yazi_shared::url::Url;
 
 use super::Tasks;
 
 impl Tasks {
-	pub fn process_from_files(&self, hovered: Url, targets: Vec<(Url, String)>) {
+	pub fn process_from_files(&self, hovered: Url, targets: Vec<(Url, Cow<str>)>) {
 		let mut openers = HashMap::new();
 		for (url, mime) in targets {
 			if let Some(opener) = OPEN.openers(&url, mime).and_then(|o| o.first().copied()) {
@@ -16,7 +16,7 @@ impl Tasks {
 		for (opener, args) in openers {
 			self.process_from_opener(
 				Cow::Borrowed(opener),
-				args.into_iter().map(|u| u.into_os_string()).collect(),
+				args.into_iter().map(|u| u.into_path().into_os_string()).collect(),
 			);
 		}
 	}
