@@ -1,10 +1,10 @@
-use yazi_shared::event::Cmd;
+use yazi_shared::event::CmdCow;
 
-use crate::{app::App, Term};
+use crate::{Term, app::App};
 
 impl App {
-	pub(crate) fn resume(&mut self, _: Cmd) {
-		self.cx.manager.active_mut().preview.reset_image();
+	pub(crate) fn resume(&mut self, _: CmdCow) {
+		self.cx.active_mut().preview.reset_image();
 		self.term = Some(Term::start().unwrap());
 
 		// While the app resumes, it's possible that the terminal size has changed.
