@@ -1,22 +1,22 @@
 use crossterm::terminal::WindowSize;
 use ratatui::layout::Rect;
 use yazi_adapter::Dimension;
-use yazi_shared::event::Cmd;
+use yazi_shared::event::CmdCow;
 
 use crate::{app::App, notify};
 
 impl App {
-	pub(crate) fn update_notify(&mut self, cmd: Cmd) {
+	pub(crate) fn update_notify(&mut self, cmd: CmdCow) {
 		let WindowSize { rows, columns, .. } = Dimension::available();
 		let area =
-			notify::Layout::available(Rect { x: 0, y: 0, width: columns, height: rows });
+			notify::Notify::available(Rect { x: 0, y: 0, width: columns, height: rows });
 
 		self.cx.notify.tick(cmd, area);
 
 		if self.cx.notify.messages.is_empty() {
 			self.render();
 		} else {
-			self.render_notify();
+			self.render_partially();
 		}
 	}
 }
