@@ -11,19 +11,21 @@ function Current:new(area, tab)
 end
 
 function Current:empty()
-	local line
+	local text
 	if self._folder.files.filter then
-		line = ui.Line("No filter results")
+		text = ui.Text("No filter results")
 	else
-		line = ui.Line(self._folder.stage.is_loading and "Loading..." or "No items")
+		text = ui.Text(self._folder.stage.is_loading and "Loading..." or "No items")
 	end
 
 	return {
-		ui.Paragraph(self._area, { line }):align(ui.Paragraph.CENTER),
+		text:area(self._area):align(ui.Text.CENTER),
 	}
 end
 
-function Current:render()
+function Current:reflow() return { self } end
+
+function Current:redraw()
 	local files = self._folder.window
 	if #files == 0 then
 		return self:empty()
@@ -31,15 +33,13 @@ function Current:render()
 
 	local entities, linemodes = {}, {}
 	for _, f in ipairs(files) do
-		linemodes[#linemodes + 1] = Linemode:new(f):render()
-
-		local entity = Entity:new(f)
-		entities[#entities + 1] = ui.ListItem(entity:render()):style(entity:style())
+		entities[#entities + 1] = Entity:new(f):redraw()
+		linemodes[#linemodes + 1] = Linemode:new(f):redraw()
 	end
 
 	return {
-		ui.List(self._area, entities),
-		ui.Paragraph(self._area, linemodes):align(ui.Paragraph.RIGHT),
+		ui.List(entities):area(self._area),
+		ui.Text(linemodes):area(self._area):align(ui.Text.RIGHT),
 	}
 end
 
