@@ -29,26 +29,34 @@ function Tab:build()
 	}
 end
 
-function Tab:render()
-	local children = self._base or {}
+function Tab:reflow()
+	local components = { self }
 	for _, child in ipairs(self._children) do
-		children = ya.list_merge(children, ya.render_with(child))
+		components = ya.list_merge(components, child:reflow())
 	end
-	return children
+	return components
+end
+
+function Tab:redraw()
+	local elements = self._base or {}
+	for _, child in ipairs(self._children) do
+		elements = ya.list_merge(elements, ya.redraw_with(child))
+	end
+	return elements
 end
 
 -- Mouse events
 function Tab:click(event, up)
-	local c = ya.child_at(ui.Position { x = event.x, y = event.y }, self._children)
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
 	return c and c:click(event, up)
 end
 
 function Tab:scroll(event, step)
-	local c = ya.child_at(ui.Position { x = event.x, y = event.y }, self._children)
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
 	return c and c:scroll(event, step)
 end
 
 function Tab:touch(event, step)
-	local c = ya.child_at(ui.Position { x = event.x, y = event.y }, self._children)
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
 	return c and c:touch(event, step)
 end
