@@ -1,15 +1,16 @@
 local M = {}
 
-function M:peek()
-	local limit = self.area.h
+function M:peek(job)
+	local limit = job.area.h
 	local paths, sizes = {}, {}
 
-	local files, bound, code = self:list_files({ "-p", tostring(self.file.url) }, self.skip, limit)
+	local files, bound, code = self.list_files({ "-p", tostring(job.file.url) }, job.skip, limit)
 	if code ~= 0 then
-		return ya.preview_widgets(self, {
-			ui.Paragraph(self.area, {
-				ui.Line(code == 2 and "File list in this archive is encrypted" or "Spawn `7z` and `7zz` both commands failed"),
-			}),
+		return ya.preview_widgets(job, {
+			ui.Text(
+				code == 2 and "File list in this archive is encrypted"
+					or "Failed to start both `7z` and `7zz`. Do you have 7-zip installed?"
+			):area(job.area),
 		})
 	end
 
@@ -20,46 +21,37 @@ function M:peek()
 		}):icon()
 
 		if icon then
-			paths[#paths + 1] = ui.Line { ui.Span(" " .. icon.text .. " "):style(icon.style), ui.Span(f.path) }
+			paths[#paths + 1] = ui.Line { ui.Span(" " .. icon.text .. " "):style(icon.style), f.path }
 		else
-			paths[#paths + 1] = ui.Line(f.path)
+			paths[#paths + 1] = f.path
 		end
 
 		if f.size > 0 then
-			sizes[#sizes + 1] = ui.Line(string.format(" %s ", ya.readable_size(f.size)))
+			sizes[#sizes + 1] = string.format(" %s ", ya.readable_size(f.size))
 		else
-			sizes[#sizes + 1] = ui.Line("")
+			sizes[#sizes + 1] = ""
 		end
 	end
 
-	if self.skip > 0 and bound < self.skip + limit then
-		ya.manager_emit("peek", { math.max(0, bound - limit), only_if = self.file.url, upper_bound = true })
+	if job.skip > 0 and bound < job.skip + limit then
+		ya.manager_emit("peek", { math.max(0, bound - limit), only_if = job.file.url, upper_bound = true })
 	else
-		ya.preview_widgets(self, {
-			ui.Paragraph(self.area, paths),
-			ui.Paragraph(self.area, sizes):align(ui.Paragraph.RIGHT),
+		ya.preview_widgets(job, {
+			ui.Text(paths):area(job.area),
+			ui.Text(sizes):area(job.area):align(ui.Text.RIGHT),
 		})
 	end
 end
 
-function M:seek(units)
-	local h = cx.active.current.hovered
-	if h and h.url == self.file.url then
-		local step = math.floor(units * self.area.h / 10)
-		ya.manager_emit("peek", {
-			math.max(0, cx.active.preview.skip + step),
-			only_if = self.file.url,
-		})
-	end
-end
+function M:seek(job) require("code"):seek(job) end
 
-function M:spawn_7z(args)
-	local last_error = nil
+function M.spawn_7z(args)
+	local last_err = nil
 	local try = function(name)
 		local stdout = args[1] == "l" and Command.PIPED or Command.NULL
-		local child, code = Command(name):args(args):stdout(stdout):stderr(Command.PIPED):spawn()
+		local child, err = Command(name):args(args):stdout(stdout):stderr(Command.PIPED):spawn()
 		if not child then
-			last_error = code
+			last_err = err
 		end
 		return child
 	end
@@ -72,24 +64,24 @@ function M:spawn_7z(args)
 	end
 
 	if not child then
-		return ya.err("spawn `7z` and `7zz` both commands failed, error code: " .. tostring(last_error))
+		return ya.err("Failed to start both `7z` and `7zz`, error: " .. last_err)
 	end
-	return child, last_error
+	return child, last_err
 end
 
 ---List files in an archive
 ---@param args table
 ---@param skip integer
 ---@param limit integer
----@return table
----@return integer
----@return integer
+---@return table files
+---@return integer bound
+---@return integer code
 ---  0: success
 ---  1: failed to spawn
 ---  2: wrong password
 ---  3: partial success
-function M:list_files(args, skip, limit)
-	local child = self:spawn_7z { "l", "-ba", "-slt", table.unpack(args) }
+function M.list_files(args, skip, limit)
+	local child = M.spawn_7z { "l", "-ba", "-slt", "-sccUTF-8", table.unpack(args) }
 	if not child then
 		return {}, 0, 1
 	end
@@ -98,7 +90,7 @@ function M:list_files(args, skip, limit)
 	local key, value = "", ""
 	repeat
 		local next, event = child:read_line()
-		if event == 1 and self:is_encrypted(next) then
+		if event == 1 and M.is_encrypted(next) then
 			code = 2
 			break
 		elseif event == 1 then
@@ -137,6 +129,49 @@ function M:list_files(args, skip, limit)
 	return files, i, code
 end
 
-function M:is_encrypted(s) return s:find(" Wrong password", 1, true) end
+---List metadata of an archive
+---@param args table
+---@return string|nil type
+---@return integer code
+---  0: success
+---  1: failed to spawn
+---  2: wrong password
+---  3: partial success
+function M.list_meta(args)
+	local child = M.spawn_7z { "l", "-slt", "-sccUTF-8", table.unpack(args) }
+	if not child then
+		return nil, 1
+	end
+
+	local i, head = 0, ""
+	local typ, code = nil, 0
+	while i < 500 do
+		i = i + 1
+
+		local next, event = child:read_line()
+		if event == 1 and M.is_encrypted(next) then
+			code = 2
+			break
+		elseif event == 1 then
+			code = 3
+		elseif event == 0 then
+			head = head .. next
+		else
+			break
+		end
+
+		typ = head:gmatch("--[\r\n]+Path = .-[\r\n]+Type = (.-)[\r\n]+")()
+		if typ then
+			break
+		end
+	end
+
+	child:start_kill()
+	return typ ~= "" and typ or nil, code
+end
+
+function M.is_encrypted(s) return s:find(" Wrong password", 1, true) end
+
+function M.is_tar(url) return M.list_meta { "-p", tostring(url) } == "tar" end
 
 return M
