@@ -1,7 +1,6 @@
 use mlua::{AnyUserData, Lua, Table, UserData, UserDataMethods};
 
-use super::{Constraint, Rect, RectRef};
-use crate::bindings::Cast;
+use super::{Constraint, Rect};
 
 const HORIZONTAL: bool = true;
 const VERTICAL: bool = false;
@@ -14,28 +13,27 @@ pub struct Layout {
 }
 
 impl Layout {
-	pub fn install(lua: &Lua, ui: &Table) -> mlua::Result<()> {
+	pub fn compose(lua: &Lua) -> mlua::Result<Table> {
 		let new = lua.create_function(|_, _: Table| Ok(Self::default()))?;
 
 		let layout = lua.create_table_from([("HORIZONTAL", HORIZONTAL), ("VERTICAL", VERTICAL)])?;
-
 		layout.set_metatable(Some(lua.create_table_from([("__call", new)])?));
 
-		ui.raw_set("Layout", layout)
+		Ok(layout)
 	}
 }
 
 impl UserData for Layout {
-	fn add_methods<'lua, M: UserDataMethods<'lua, Self>>(methods: &mut M) {
-		methods.add_function("direction", |_, (ud, value): (AnyUserData, bool)| {
+	fn add_methods<M: UserDataMethods<Self>>(methods: &mut M) {
+		methods.add_function_mut("direction", |_, (ud, value): (AnyUserData, bool)| {
 			ud.borrow_mut::<Self>()?.direction = value;
 			Ok(ud)
 		});
-		methods.add_function("margin", |_, (ud, value): (AnyUserData, u16)| {
+		methods.add_function_mut("margin", |_, (ud, value): (AnyUserData, u16)| {
 			ud.borrow_mut::<Self>()?.margin = Some(ratatui::layout::Margin::new(value, value));
 			Ok(ud)
 		});
-		methods.add_function("margin_h", |_, (ud, value): (AnyUserData, u16)| {
+		methods.add_function_mut("margin_h", |_, (ud, value): (AnyUserData, u16)| {
 			{
 				let mut me = ud.borrow_mut::<Self>()?;
 				if let Some(margin) = &mut me.margin {
@@ -46,7 +44,7 @@ impl UserData for Layout {
 			}
 			Ok(ud)
 		});
-		methods.add_function("margin_v", |_, (ud, value): (AnyUserData, u16)| {
+		methods.add_function_mut("margin_v", |_, (ud, value): (AnyUserData, u16)| {
 			{
 				let mut me = ud.borrow_mut::<Self>()?;
 				if let Some(margin) = &mut me.margin {
@@ -57,11 +55,11 @@ impl UserData for Layout {
 			}
 			Ok(ud)
 		});
-		methods.add_function("constraints", |_, (ud, value): (AnyUserData, Vec<Constraint>)| {
-			ud.borrow_mut::<Self>()?.constraints = value.into_iter().map(|c| c.0).collect();
+		methods.add_function_mut("constraints", |_, (ud, value): (AnyUserData, Vec<Constraint>)| {
+			ud.borrow_mut::<Self>()?.constraints = value.into_iter().map(Into::into).collect();
 			Ok(ud)
 		});
-		methods.add_method("split", |lua, me, value: RectRef| {
+		methods.add_method("split", |lua, me, value: Rect| {
 			let mut layout = ratatui::layout::Layout::new(
 				if me.direction == VERTICAL {
 					ratatui::layout::Direction::Vertical
@@ -76,11 +74,7 @@ impl UserData for Layout {
 				layout = layout.vertical_margin(margin.vertical);
 			}
 
-			let mut chunks = Vec::with_capacity(me.constraints.len());
-			for chunk in &*layout.split(*value) {
-				chunks.push(Rect::cast(lua, *chunk)?);
-			}
-			Ok(chunks)
+			lua.create_sequence_from(layout.split(*value).iter().map(|chunk| Rect::from(*chunk)))
 		});
 	}
 }
