@@ -1,14 +1,14 @@
-use std::{borrow::Cow, io::Cursor, mem, path::{Path, PathBuf}, sync::atomic::{AtomicUsize, Ordering}};
+use std::{borrow::Cow, io::Cursor, mem, path::{Path, PathBuf}, sync::OnceLock};
 
-use anyhow::{anyhow, Result};
-use ratatui::{layout::Rect, text::{Line, Span, Text}};
-use syntect::{dumps, easy::HighlightLines, highlighting::{self, Theme, ThemeSet}, parsing::{SyntaxReference, SyntaxSet}, LoadingError};
-use tokio::{fs::File, io::{AsyncBufReadExt, BufReader}, sync::OnceCell};
-use yazi_config::{preview::PreviewWrap, PREVIEW, THEME};
-use yazi_shared::PeekError;
+use anyhow::{Result, anyhow};
+use ratatui::{layout::Size, text::{Line, Span, Text}};
+use syntect::{LoadingError, dumps, easy::HighlightLines, highlighting::{self, Theme, ThemeSet}, parsing::{SyntaxReference, SyntaxSet}};
+use tokio::{fs::File, io::{AsyncBufReadExt, BufReader}};
+use yazi_config::{PREVIEW, THEME, preview::PreviewWrap};
+use yazi_shared::{Ids, errors::PeekError, replace_to_printable};
 
-static INCR: AtomicUsize = AtomicUsize::new(0);
-static SYNTECT: OnceCell<(Theme, SyntaxSet)> = OnceCell::const_new();
+static INCR: Ids = Ids::new();
+static SYNTECT: OnceLock<(Theme, SyntaxSet)> = OnceLock::new();
 
 pub struct Highlighter {
 	path: PathBuf,
@@ -18,37 +18,33 @@ impl Highlighter {
 	#[inline]
 	pub fn new(path: &Path) -> Self { Self { path: path.to_owned() } }
 
-	pub async fn init() -> (&'static Theme, &'static SyntaxSet) {
-		let fut = async {
-			tokio::task::spawn_blocking(|| {
-				let theme = std::fs::File::open(&THEME.manager.syntect_theme)
-					.map_err(LoadingError::Io)
-					.and_then(|f| ThemeSet::load_from_reader(&mut std::io::BufReader::new(f)))
-					.or_else(|_| ThemeSet::load_from_reader(&mut Cursor::new(yazi_prebuild::ansi_theme())));
+	pub fn init() -> (&'static Theme, &'static SyntaxSet) {
+		let f = || {
+			let theme = std::fs::File::open(&THEME.manager.syntect_theme)
+				.map_err(LoadingError::Io)
+				.and_then(|f| ThemeSet::load_from_reader(&mut std::io::BufReader::new(f)))
+				.or_else(|_| ThemeSet::load_from_reader(&mut Cursor::new(yazi_prebuild::ansi_theme())));
 
-				let syntaxes = dumps::from_uncompressed_data(yazi_prebuild::syntaxes());
+			let syntaxes = dumps::from_uncompressed_data(yazi_prebuild::syntaxes());
 
-				(theme.unwrap(), syntaxes.unwrap())
-			})
-			.await
-			.unwrap()
+			(theme.unwrap(), syntaxes.unwrap())
 		};
 
-		let r = SYNTECT.get_or_init(|| fut).await;
-		(&r.0, &r.1)
+		let (theme, syntaxes) = SYNTECT.get_or_init(f);
+		(theme, syntaxes)
 	}
 
 	#[inline]
-	pub fn abort() { INCR.fetch_add(1, Ordering::Relaxed); }
+	pub fn abort() { INCR.next(); }
 
-	pub async fn highlight(&self, skip: usize, area: Rect) -> Result<Text<'static>, PeekError> {
+	pub async fn highlight(&self, skip: usize, size: Size) -> Result<Text<'static>, PeekError> {
 		let mut reader = BufReader::new(File::open(&self.path).await?);
 
 		let syntax = Self::find_syntax(&self.path).await;
 		let mut plain = syntax.is_err();
 
 		let mut before = Vec::with_capacity(if plain { 0 } else { skip });
-		let mut after = Vec::with_capacity(area.height as _);
+		let mut after = Vec::with_capacity(size.height as _);
 
 		let mut i = 0;
 		let mut buf = vec![];
@@ -58,7 +54,7 @@ impl Highlighter {
 				return Err("Binary file".into());
 			}
 
-			if !plain && (buf.len() > 5000 || buf.contains(&0x1b)) {
+			if !plain && (buf.len() > 5000 || Self::contains_control_chars(&buf)) {
 				plain = true;
 				drop(mem::take(&mut before));
 			}
@@ -72,28 +68,28 @@ impl Highlighter {
 			i += if i >= skip {
 				buf.iter_mut().for_each(Self::carriage_return_to_line_feed);
 				after.push(String::from_utf8_lossy(&buf).into_owned());
-				Self::line_height(&after[after.len() - 1], area.width)
+				Self::line_height(&after[after.len() - 1], size.width)
 			} else if !plain {
 				before.push(String::from_utf8_lossy(&buf).into_owned());
-				Self::line_height(&before[before.len() - 1], area.width)
+				Self::line_height(&before[before.len() - 1], size.width)
 			} else if PREVIEW.wrap == PreviewWrap::Yes {
-				Self::line_height(&String::from_utf8_lossy(&buf), area.width)
+				Self::line_height(&String::from_utf8_lossy(&buf), size.width)
 			} else {
 				1
 			};
 
 			buf.clear();
-			if i > skip + area.height as usize {
+			if i > skip + size.height as usize {
 				break;
 			}
 		}
 
-		if skip > 0 && i < skip + area.height as usize {
-			return Err(PeekError::Exceed(i.saturating_sub(area.height as _)));
+		if skip > 0 && i < skip + size.height as usize {
+			return Err(PeekError::Exceed(i.saturating_sub(size.height as _)));
 		}
 
 		Ok(if plain {
-			Text::from(after.join("").replace('\x1b', "^[").replace('\t', &PREVIEW.indent()))
+			Text::from(replace_to_printable(&after, PREVIEW.tab_size))
 		} else {
 			Self::highlight_with(before, after, syntax.unwrap()).await?
 		})
@@ -104,13 +100,14 @@ impl Highlighter {
 		after: Vec<String>,
 		syntax: &'static SyntaxReference,
 	) -> Result<Text<'static>, PeekError> {
-		let ticket = INCR.load(Ordering::Relaxed);
-		let (theme, syntaxes) = Self::init().await;
+		let ticket = INCR.current();
 
 		tokio::task::spawn_blocking(move || {
+			let (theme, syntaxes) = Self::init();
 			let mut h = HighlightLines::new(syntax, theme);
+
 			for line in before {
-				if ticket != INCR.load(Ordering::Relaxed) {
+				if ticket != INCR.current() {
 					return Err("Highlighting cancelled".into());
 				}
 				h.highlight_line(&line, syntaxes).map_err(|e| anyhow!(e))?;
@@ -119,7 +116,7 @@ impl Highlighter {
 			let indent = PREVIEW.indent();
 			let mut lines = Vec::with_capacity(after.len());
 			for line in after {
-				if ticket != INCR.load(Ordering::Relaxed) {
+				if ticket != INCR.current() {
 					return Err("Highlighting cancelled".into());
 				}
 
@@ -133,7 +130,7 @@ impl Highlighter {
 	}
 
 	async fn find_syntax(path: &Path) -> Result<&'static SyntaxReference> {
-		let (_, syntaxes) = Self::init().await;
+		let (_, syntaxes) = Self::init();
 		let name = path.file_name().map(|n| n.to_string_lossy()).unwrap_or_default();
 		if let Some(s) = syntaxes.find_syntax_by_extension(&name) {
 			return Ok(s);
@@ -186,9 +183,14 @@ impl Highlighter {
 	}
 
 	#[inline(always)]
-	fn carriage_return_to_line_feed(c: &mut u8) {
-		if *c == b'\r' {
-			*c = b'\n';
+	fn contains_control_chars(buf: &[u8]) -> bool {
+		buf.iter().any(|&b| b.is_ascii_control() && !matches!(b, b'\t' | b'\n' | b'\r'))
+	}
+
+	#[inline(always)]
+	fn carriage_return_to_line_feed(b: &mut u8) {
+		if *b == b'\r' {
+			*b = b'\n';
 		}
 	}
 }
