@@ -1,15 +1,16 @@
 use std::collections::{HashMap, HashSet};
 
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use parking_lot::{Mutex, RwLock};
 use tokio::sync::mpsc;
 use tracing::error;
 use yazi_config::Priority;
+use yazi_fs::{FilesOp, calculate_size};
 use yazi_plugin::isolate;
-use yazi_shared::fs::{calculate_size, FilesOp, Url};
+use yazi_shared::{event::CmdCow, url::Url};
 
 use super::{PreworkOp, PreworkOpFetch, PreworkOpLoad, PreworkOpSize};
-use crate::{TaskOp, TaskProg, HIGH, NORMAL};
+use crate::{HIGH, NORMAL, TaskOp, TaskProg};
 
 pub struct Prework {
 	macro_: async_priority_channel::Sender<TaskOp, u8>,
@@ -30,14 +31,14 @@ impl Prework {
 	pub async fn work(&self, op: PreworkOp) -> Result<()> {
 		match op {
 			PreworkOp::Fetch(task) => {
-				let urls: Vec<_> = task.targets.iter().map(|f| f.url()).collect();
-				let result = isolate::fetch(&task.plugin.name, task.targets).await;
+				let urls: Vec<_> = task.targets.iter().map(|f| f.url_owned()).collect();
+				let result = isolate::fetch(CmdCow::from(&task.plugin.run), task.targets).await;
 				if let Err(e) = result {
 					self.fail(
 						task.id,
 						format!(
 							"Failed to run fetcher `{}` with:\n{}\n\nError message:\n{e}",
-							task.plugin.name,
+							task.plugin.run.name,
 							urls.iter().map(ToString::to_string).collect::<Vec<_>>().join("\n")
 						),
 					)?;
@@ -48,36 +49,36 @@ impl Prework {
 				if code & 1 == 0 {
 					error!(
 						"Returned {code} when running fetcher `{}` with:\n{}",
-						task.plugin.name,
+						task.plugin.run.name,
 						urls.iter().map(ToString::to_string).collect::<Vec<_>>().join("\n")
 					);
 				}
 				if code & 2 != 0 {
 					let mut loaded = self.loaded.lock();
 					for url in urls {
-						loaded.get_mut(&url).map(|x| *x &= !(1 << task.plugin.id));
+						loaded.get_mut(&url).map(|x| *x &= !(1 << task.plugin.idx));
 					}
 				}
 				self.prog.send(TaskProg::Adv(task.id, 1, 0))?;
 			}
 			PreworkOp::Load(task) => {
-				let url = task.target.url();
-				let result = isolate::preload(&task.plugin.name, task.target).await;
+				let url = task.target.url_owned();
+				let result = isolate::preload(&task.plugin.run, task.target).await;
 				if let Err(e) = result {
 					self.fail(
 						task.id,
-						format!("Failed to run preloader `{}` with `{url}`:\n{e}", task.plugin.name),
+						format!("Failed to run preloader `{}` with `{url}`:\n{e}", task.plugin.run.name),
 					)?;
 					return Err(e.into());
 				};
 
 				let code = result.unwrap();
 				if code & 1 == 0 {
-					error!("Returned {code} when running preloader `{}` with `{url}`", task.plugin.name);
+					error!("Returned {code} when running preloader `{}` with `{url}`", task.plugin.run.name);
 				}
 				if code & 2 != 0 {
 					let mut loaded = self.loaded.lock();
-					loaded.get_mut(&url).map(|x| *x &= !(1 << task.plugin.id));
+					loaded.get_mut(&url).map(|x| *x &= !(1 << task.plugin.idx));
 				}
 				self.prog.send(TaskProg::Adv(task.id, 1, 0))?;
 			}
@@ -92,7 +93,11 @@ impl Prework {
 					}
 
 					let parent = buf[0].0.parent_url().unwrap();
-					FilesOp::Size(parent, HashMap::from_iter(buf)).emit();
+					FilesOp::Size(
+						parent,
+						HashMap::from_iter(buf.into_iter().map(|(u, s)| (u.urn_owned(), s))),
+					)
+					.emit();
 				});
 				self.prog.send(TaskProg::Adv(task.id, 1, 0))?;
 			}
