@@ -1,16 +1,17 @@
-use std::{borrow::Cow, ffi::OsString, sync::Arc, time::Duration};
+use std::{borrow::Cow, ffi::OsString, future::Future, sync::Arc, time::Duration};
 
 use anyhow::Result;
-use futures::{future::BoxFuture, FutureExt};
+use futures::{FutureExt, future::BoxFuture};
 use parking_lot::Mutex;
 use tokio::{fs, select, sync::{mpsc::{self, UnboundedReceiver}, oneshot}, task::JoinHandle};
-use yazi_config::{open::Opener, plugin::{Fetcher, Preloader}, TASKS};
+use yazi_config::{TASKS, open::Opener, plugin::{Fetcher, Preloader}};
 use yazi_dds::Pump;
-use yazi_proxy::ManagerProxy;
-use yazi_shared::{event::Data, fs::{remove_dir_clean, unique_name, Url}, Throttle};
+use yazi_fs::{must_be_dir, remove_dir_clean, unique_name};
+use yazi_proxy::{ManagerProxy, options::PluginOpt};
+use yazi_shared::{Throttle, url::Url};
 
 use super::{Ongoing, TaskProg, TaskStage};
-use crate::{file::{File, FileOpDelete, FileOpHardlink, FileOpLink, FileOpPaste, FileOpTrash}, plugin::{Plugin, PluginOpEntry}, prework::{Prework, PreworkOpFetch, PreworkOpLoad, PreworkOpSize}, process::{Process, ProcessOpBg, ProcessOpBlock, ProcessOpOrphan}, TaskKind, TaskOp, HIGH, LOW, NORMAL};
+use crate::{HIGH, LOW, NORMAL, TaskKind, TaskOp, file::{File, FileOpDelete, FileOpHardlink, FileOpLink, FileOpPaste, FileOpTrash}, plugin::{Plugin, PluginOpEntry}, prework::{Prework, PreworkOpFetch, PreworkOpLoad, PreworkOpSize}, process::{Process, ProcessOpBg, ProcessOpBlock, ProcessOpOrphan}};
 
 pub struct Scheduler {
 	pub file:    Arc<File>,
@@ -71,7 +72,7 @@ impl Scheduler {
 
 	pub fn file_cut(&self, from: Url, mut to: Url, force: bool) {
 		let mut ongoing = self.ongoing.lock();
-		let id = ongoing.add(TaskKind::User, format!("Cut {:?} to {:?}", from, to));
+		let id = ongoing.add(TaskKind::User, format!("Cut {from} to {to}"));
 
 		if to.starts_with(&from) && to != from {
 			self.new_and_fail(id, "Cannot cut directory into itself").ok();
@@ -95,24 +96,16 @@ impl Scheduler {
 		});
 
 		let file = self.file.clone();
-		_ = self.micro.try_send(
-			async move {
-				if !force {
-					to = unique_name(to).await;
-				}
-				file
-					.paste(FileOpPaste { id, from, to, meta: None, cut: true, follow: false, retry: 0 })
-					.await
-					.ok();
+		self.send_micro(id, LOW, async move {
+			if !force {
+				to = unique_name(to, must_be_dir(&from)).await?;
 			}
-			.boxed(),
-			LOW,
-		);
+			file.paste(FileOpPaste { id, from, to, cha: None, cut: true, follow: false, retry: 0 }).await
+		});
 	}
 
 	pub fn file_copy(&self, from: Url, mut to: Url, force: bool, follow: bool) {
-		let name = format!("Copy {:?} to {:?}", from, to);
-		let id = self.ongoing.lock().add(TaskKind::User, name);
+		let id = self.ongoing.lock().add(TaskKind::User, format!("Copy {from} to {to}"));
 
 		if to.starts_with(&from) && to != from {
 			self.new_and_fail(id, "Cannot copy directory into itself").ok();
@@ -120,44 +113,30 @@ impl Scheduler {
 		}
 
 		let file = self.file.clone();
-		_ = self.micro.try_send(
-			async move {
-				if !force {
-					to = unique_name(to).await;
-				}
-				file
-					.paste(FileOpPaste { id, from, to, meta: None, cut: false, follow, retry: 0 })
-					.await
-					.ok();
+		self.send_micro(id, LOW, async move {
+			if !force {
+				to = unique_name(to, must_be_dir(&from)).await?;
 			}
-			.boxed(),
-			LOW,
-		);
+			file.paste(FileOpPaste { id, from, to, cha: None, cut: false, follow, retry: 0 }).await
+		});
 	}
 
 	pub fn file_link(&self, from: Url, mut to: Url, relative: bool, force: bool) {
-		let name = format!("Link {from:?} to {to:?}");
-		let id = self.ongoing.lock().add(TaskKind::User, name);
+		let id = self.ongoing.lock().add(TaskKind::User, format!("Link {from} to {to}"));
 
 		let file = self.file.clone();
-		_ = self.micro.try_send(
-			async move {
-				if !force {
-					to = unique_name(to).await;
-				}
-				file
-					.link(FileOpLink { id, from, to, meta: None, resolve: false, relative, delete: false })
-					.await
-					.ok();
+		self.send_micro(id, LOW, async move {
+			if !force {
+				to = unique_name(to, must_be_dir(&from)).await?;
 			}
-			.boxed(),
-			LOW,
-		);
+			file
+				.link(FileOpLink { id, from, to, cha: None, resolve: false, relative, delete: false })
+				.await
+		});
 	}
 
 	pub fn file_hardlink(&self, from: Url, mut to: Url, force: bool, follow: bool) {
-		let name = format!("Hardlink {:?} to {:?}", from, to);
-		let id = self.ongoing.lock().add(TaskKind::User, name);
+		let id = self.ongoing.lock().add(TaskKind::User, format!("Hardlink {from} to {to}"));
 
 		if to.starts_with(&from) && to != from {
 			self.new_and_fail(id, "Cannot hardlink directory into itself").ok();
@@ -165,21 +144,17 @@ impl Scheduler {
 		}
 
 		let file = self.file.clone();
-		_ = self.micro.try_send(
-			async move {
-				if !force {
-					to = unique_name(to).await;
-				}
-				file.hardlink(FileOpHardlink { id, from, to, meta: None, follow }).await.ok();
+		self.send_micro(id, LOW, async move {
+			if !force {
+				to = unique_name(to, must_be_dir(&from)).await?;
 			}
-			.boxed(),
-			LOW,
-		);
+			file.hardlink(FileOpHardlink { id, from, to, cha: None, follow }).await
+		});
 	}
 
 	pub fn file_delete(&self, target: Url) {
 		let mut ongoing = self.ongoing.lock();
-		let id = ongoing.add(TaskKind::User, format!("Delete {:?}", target));
+		let id = ongoing.add(TaskKind::User, format!("Delete {target}"));
 
 		ongoing.hooks.insert(id, {
 			let target = target.clone();
@@ -189,7 +164,7 @@ impl Scheduler {
 				async move {
 					if !canceled {
 						fs::remove_dir_all(&target).await.ok();
-						ManagerProxy::update_task(&target);
+						ManagerProxy::update_tasks(&target);
 						Pump::push_delete(target);
 					}
 					ongoing.lock().try_remove(id, TaskStage::Hooked);
@@ -199,18 +174,16 @@ impl Scheduler {
 		});
 
 		let file = self.file.clone();
-		_ = self.micro.try_send(
-			async move {
-				file.delete(FileOpDelete { id, target, length: 0 }).await.ok();
-			}
-			.boxed(),
+		self.send_micro(
+			id,
 			LOW,
+			async move { file.delete(FileOpDelete { id, target, length: 0 }).await },
 		);
 	}
 
 	pub fn file_trash(&self, target: Url) {
 		let mut ongoing = self.ongoing.lock();
-		let id = ongoing.add(TaskKind::User, format!("Trash {:?}", target));
+		let id = ongoing.add(TaskKind::User, format!("Trash {target}"));
 
 		ongoing.hooks.insert(id, {
 			let target = target.clone();
@@ -219,7 +192,7 @@ impl Scheduler {
 			Box::new(move |canceled: bool| {
 				async move {
 					if !canceled {
-						ManagerProxy::update_task(&target);
+						ManagerProxy::update_tasks(&target);
 						Pump::push_trash(target);
 					}
 					ongoing.lock().try_remove(id, TaskStage::Hooked);
@@ -229,65 +202,45 @@ impl Scheduler {
 		});
 
 		let file = self.file.clone();
-		_ = self.micro.try_send(
-			async move {
-				file.trash(FileOpTrash { id, target: target.clone(), length: 0 }).await.ok();
-			}
-			.boxed(),
-			LOW,
-		);
+		self.send_micro(id, LOW, async move {
+			file.trash(FileOpTrash { id, target: target.clone(), length: 0 }).await
+		})
 	}
 
-	pub fn plugin_micro(&self, name: String, args: Vec<Data>) {
-		let id = self.ongoing.lock().add(TaskKind::User, format!("Run micro plugin `{name}`"));
+	pub fn plugin_micro(&self, opt: PluginOpt) {
+		let id = self.ongoing.lock().add(TaskKind::User, format!("Run micro plugin `{}`", opt.id));
 
 		let plugin = self.plugin.clone();
-		_ = self.micro.try_send(
-			async move {
-				plugin.micro(PluginOpEntry { id, name, args }).await.ok();
-			}
-			.boxed(),
-			NORMAL,
-		);
+		self.send_micro(id, NORMAL, async move { plugin.micro(PluginOpEntry { id, opt }).await });
 	}
 
-	pub fn plugin_macro(&self, name: String, args: Vec<Data>) {
-		let id = self.ongoing.lock().add(TaskKind::User, format!("Run macro plugin `{name}`"));
+	pub fn plugin_macro(&self, opt: PluginOpt) {
+		let id = self.ongoing.lock().add(TaskKind::User, format!("Run macro plugin `{}`", opt.id));
 
-		self.plugin.macro_(PluginOpEntry { id, name, args }).ok();
+		self.plugin.macro_(PluginOpEntry { id, opt }).ok();
 	}
 
-	pub fn fetch_paged(&self, fetcher: &Fetcher, targets: Vec<yazi_shared::fs::File>) {
+	pub fn fetch_paged(&self, fetcher: &'static Fetcher, targets: Vec<yazi_fs::File>) {
 		let id = self.ongoing.lock().add(
 			TaskKind::Preload,
 			format!("Run fetcher `{}` with {} target(s)", fetcher.run.name, targets.len()),
 		);
 
-		let plugin = fetcher.into();
 		let prework = self.prework.clone();
-		_ = self.micro.try_send(
-			async move {
-				prework.fetch(PreworkOpFetch { id, plugin, targets }).await.ok();
-			}
-			.boxed(),
-			NORMAL,
-		);
+		self.send_micro(id, NORMAL, async move {
+			prework.fetch(PreworkOpFetch { id, plugin: fetcher, targets }).await
+		});
 	}
 
-	pub fn preload_paged(&self, preloader: &Preloader, target: &yazi_shared::fs::File) {
+	pub fn preload_paged(&self, preloader: &'static Preloader, target: &yazi_fs::File) {
 		let id =
 			self.ongoing.lock().add(TaskKind::Preload, format!("Run preloader `{}`", preloader.run.name));
 
-		let plugin = preloader.into();
 		let target = target.clone();
 		let prework = self.prework.clone();
-		_ = self.micro.try_send(
-			async move {
-				prework.load(PreworkOpLoad { id, plugin, target }).await.ok();
-			}
-			.boxed(),
-			NORMAL,
-		);
+		self.send_micro(id, NORMAL, async move {
+			prework.load(PreworkOpLoad { id, plugin: preloader, target }).await
+		});
 	}
 
 	pub fn prework_size(&self, targets: Vec<&Url>) {
@@ -295,18 +248,14 @@ impl Scheduler {
 		let mut ongoing = self.ongoing.lock();
 
 		for target in targets {
-			let id = ongoing.add(TaskKind::Preload, format!("Calculate the size of {:?}", target));
+			let id = ongoing.add(TaskKind::Preload, format!("Calculate the size of {target}"));
 			let target = target.clone();
 			let throttle = throttle.clone();
 
 			let prework = self.prework.clone();
-			_ = self.micro.try_send(
-				async move {
-					prework.size(PreworkOpSize { id, target, throttle }).await.ok();
-				}
-				.boxed(),
-				NORMAL,
-			);
+			self.send_micro(id, NORMAL, async move {
+				prework.size(PreworkOpSize { id, target, throttle }).await
+			});
 		}
 	}
 
@@ -348,19 +297,15 @@ impl Scheduler {
 
 		let cmd = OsString::from(&opener.run);
 		let process = self.process.clone();
-		_ = self.micro.try_send(
-			async move {
-				if opener.block {
-					process.block(ProcessOpBlock { id, cmd, args }).await.ok();
-				} else if opener.orphan {
-					process.orphan(ProcessOpOrphan { id, cmd, args }).await.ok();
-				} else {
-					process.bg(ProcessOpBg { id, cmd, args, cancel: cancel_rx }).await.ok();
-				}
+		self.send_micro(id, NORMAL, async move {
+			if opener.block {
+				process.block(ProcessOpBlock { id, cmd, args }).await
+			} else if opener.orphan {
+				process.orphan(ProcessOpOrphan { id, cmd, args }).await
+			} else {
+				process.bg(ProcessOpBg { id, cmd, args, cancel: cancel_rx }).await
 			}
-			.boxed(),
-			NORMAL,
-		);
+		});
 	}
 
 	fn schedule_micro(
@@ -471,6 +416,23 @@ impl Scheduler {
 		})
 	}
 
+	fn send_micro<F>(&self, id: usize, priority: u8, f: F)
+	where
+		F: Future<Output = Result<()>> + Send + 'static,
+	{
+		let prog = self.prog.clone();
+		_ = self.micro.try_send(
+			async move {
+				if let Err(e) = f.await {
+					prog.send(TaskProg::New(id, 0)).ok();
+					prog.send(TaskProg::Fail(id, format!("Task initialization failed:\n{e:?}"))).ok();
+				}
+			}
+			.boxed(),
+			priority,
+		);
+	}
+
 	fn new_and_fail(&self, id: usize, reason: &str) -> Result<()> {
 		self.prog.send(TaskProg::New(id, 0))?;
 		self.prog.send(TaskProg::Fail(id, reason.to_owned()))?;
