@@ -8,7 +8,8 @@ pub enum Layer {
 	App,
 	Manager,
 	Tasks,
-	Select,
+	Spot,
+	Pick,
 	Input,
 	Confirm,
 	Help,
@@ -22,7 +23,8 @@ impl Display for Layer {
 			Self::App => "app",
 			Self::Manager => "manager",
 			Self::Tasks => "tasks",
-			Self::Select => "select",
+			Self::Spot => "spot",
+			Self::Pick => "pick",
 			Self::Input => "input",
 			Self::Confirm => "confirm",
 			Self::Help => "help",
@@ -40,7 +42,8 @@ impl FromStr for Layer {
 			"app" => Self::App,
 			"manager" => Self::Manager,
 			"tasks" => Self::Tasks,
-			"select" => Self::Select,
+			"spot" => Self::Spot,
+			"pick" => Self::Pick,
 			"input" => Self::Input,
 			"confirm" => Self::Confirm,
 			"help" => Self::Help,
